@@ -322,7 +322,6 @@ where
                 alighting_duration: stop_time.alighting_duration,
                 pickup_type: stop_time.pickup_type,
                 drop_off_type: stop_time.drop_off_type,
-                datetime_estimated,
                 local_zone_id: stop_time.local_zone_id,
                 precision,
             });
@@ -801,7 +800,6 @@ mod tests {
                         alighting_duration: 0,
                         pickup_type: 0,
                         drop_off_type: 0,
-                        datetime_estimated: false,
                         local_zone_id: None,
                         precision: Some(StopTimePrecision::Exact),
                     },
@@ -814,7 +812,6 @@ mod tests {
                         alighting_duration: 0,
                         pickup_type: 2,
                         drop_off_type: 1,
-                        datetime_estimated: false,
                         local_zone_id: None,
                         precision: Some(StopTimePrecision::Approximate),
                     },
@@ -827,7 +824,6 @@ mod tests {
                         alighting_duration: 0,
                         pickup_type: 2,
                         drop_off_type: 1,
-                        datetime_estimated: false,
                         local_zone_id: None,
                         precision: Some(StopTimePrecision::Estimated),
                     },
@@ -840,7 +836,6 @@ mod tests {
                         alighting_duration: 0,
                         pickup_type: 2,
                         drop_off_type: 1,
-                        datetime_estimated: false,
                         local_zone_id: None,
                         precision: Some(StopTimePrecision::Exact),
                     },
@@ -853,7 +848,6 @@ mod tests {
                         alighting_duration: 0,
                         pickup_type: 2,
                         drop_off_type: 1,
-                        datetime_estimated: true,
                         local_zone_id: None,
                         precision: Some(StopTimePrecision::Estimated),
                     },
